@@ -162,6 +162,7 @@ def test_page_offset(nvme0, nvme0n1, qpair, buf, offset):
 
     # read the data to different offset and check lba
     buf.offset = offset
+    buf.size = 512
     nvme0n1.read(qpair, buf, 0x5aa5).waitdone()
     assert buf[offset] == 0xa5
     assert buf[offset+1] == 0x5a
@@ -176,6 +177,7 @@ def test_page_offset_invalid(nvme0, nvme0n1, qpair, offset):
     # read the data to different offset and check lba
     buf = Buffer(1024, ptype=0, pvalue=1)
     buf.offset = offset
+    buf.size = 512
 
     # Spec NVM-Express-1_4-2019.06.10-Ratified
     # Figure 108:Note: The controller is not required to check that bits 1:0
@@ -189,20 +191,25 @@ def test_page_offset_invalid(nvme0, nvme0n1, qpair, offset):
 def test_admin_page_offset(nvme0, offset):
     buf = d.Buffer(4096*2, 'controller identify data')
     buf.offset = offset
+    buf.size = 4096
+    assert buf[0] == 0
     assert buf[offset] == 0
     nvme0.identify(buf).waitdone()
-    logging.info(buf.dump(32))
-    assert buf[0] == 0
     assert buf[offset] != 0
+    assert buf[0] == 0
 
 
-@pytest.mark.parametrize("offset", [1, 2, 3, 501, 502])
+@pytest.mark.parametrize("offset", [1, 2, 3])
 def test_admin_page_offset_invalid(nvme0, nvme0n1, qpair, offset):
     buf = d.Buffer(4096*2, 'controller identify data')
     buf.offset = offset
+    buf.size = 32  # PRP1 only
+    assert buf[0] == 0
+    assert buf[offset] == 0
     # pytest warning may not appear here
-    with pytest.warns(UserWarning, match="ERROR status: 00/13"):
-        nvme0.identify(buf).waitdone()
+    nvme0.identify(buf).waitdone()
+    logging.info(buf.dump(16))
+    assert buf[0] != 0
 
 
 def test_valid_offset_prp_in_list(nvme0):
